Class: Persona::AccountLink::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/persona/account_link.rb

Overview

agent_uid is set only when the browser must persist a (new) one via setAgentId — i.e. the anonymous cases. merge_preview is present only when confirmation is required, in which case NOTHING was changed.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_uidObject

Returns the value of attribute agent_uid

Returns:

  • (Object)

    the current value of agent_uid



41
42
43
# File 'lib/persona/account_link.rb', line 41

def agent_uid
  @agent_uid
end

#merge_previewObject

Returns the value of attribute merge_preview

Returns:

  • (Object)

    the current value of merge_preview



41
42
43
# File 'lib/persona/account_link.rb', line 41

def merge_preview
  @merge_preview
end

#mergedObject

Returns the value of attribute merged

Returns:

  • (Object)

    the current value of merged



41
42
43
# File 'lib/persona/account_link.rb', line 41

def merged
  @merged
end

#userObject

Returns the value of attribute user

Returns:

  • (Object)

    the current value of user



41
42
43
# File 'lib/persona/account_link.rb', line 41

def user
  @user
end