Class: Persona::AccountLink::Result
- Inherits:
-
Struct
- Object
- Struct
- Persona::AccountLink::Result
- Defined in:
- lib/persona/account_link.rb
Overview
agent_uid is set only when the browser must persist a (new) one via setAgentId — i.e. the anonymous cases. merge_preview is present only when confirmation is required, in which case NOTHING was changed.
Instance Attribute Summary collapse
-
#agent_uid ⇒ Object
Returns the value of attribute agent_uid.
-
#merge_preview ⇒ Object
Returns the value of attribute merge_preview.
-
#merged ⇒ Object
Returns the value of attribute merged.
-
#user ⇒ Object
Returns the value of attribute user.
Instance Attribute Details
#agent_uid ⇒ Object
Returns the value of attribute agent_uid
41 42 43 |
# File 'lib/persona/account_link.rb', line 41 def agent_uid @agent_uid end |
#merge_preview ⇒ Object
Returns the value of attribute merge_preview
41 42 43 |
# File 'lib/persona/account_link.rb', line 41 def merge_preview @merge_preview end |
#merged ⇒ Object
Returns the value of attribute merged
41 42 43 |
# File 'lib/persona/account_link.rb', line 41 def merged @merged end |
#user ⇒ Object
Returns the value of attribute user
41 42 43 |
# File 'lib/persona/account_link.rb', line 41 def user @user end |